@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
+#include<unistd.h> 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -88,7 +88,7 @@ void print_usage_and_exit(char *prog)
 	cout << " Options:" << endl;
 	cout << "  -l L           set word length, default=" << DEF_L << endl;
 	cout << "  -k K           set number of informative columns, default=" << DEF_K << endl;
-	cout << "  -d maxMismatch set maximum number of mismatches to consider, default=L" << endl;
+	cout << "  -d maxMismatch set maximum number of mismatches to consider, default=" << DEF_D << endl;
 	cout << "  -m maxSeqLen   set maximum sequence length in the sequence files," << endl;
 	cout << "                 default=" << DEF_MAXSEQLEN << endl;
 	cout << "  -n maxNumSeq   set maximum number of sequences in the sequence files," << endl;
@@ -119,7 +119,7 @@ int main(int argc, char** argv) // mainSVMclassify
 
 	opt.L = DEF_L; 
 	opt.K = DEF_K; 
-	opt.maxnmm = -1; //auto 
+	opt.maxnmm = DEF_D;
 	opt.maxseqlen = DEF_MAXSEQLEN; 
 	opt.maxnumseq = DEF_MAXNUMSEQ; 
 	opt.useTgkm = DEF_TGKM; 
